==> anaconda-navigator-1.1.1-py34_1.tar.bz2: lib/python3.4/site-packages/anaconda_navigator/images/__init__.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2016 Continuum Analytics, Inc.
# May be copied and distributed freely only as part of an Anaconda or
# Miniconda installation.
#

"""
This folder contains image files bundled with Anaconda Navigator package.

This folder is defined as a python module so that some convenience global
variables can be defined.
"""

# Standard library imports
from __future__ import absolute_import, division, print_function
import os.path as osp


IMAGE_PATH = osp.dirname(osp.realpath(__file__))

# --- Anaconda Logo
# -----------------------------------------------------------------------------
ANACONDA_ICON_16_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-16x16.png')
ANACONDA_ICON_24_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-24x24.png')
ANACONDA_ICON_32_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-32x32.png')
ANACONDA_ICON_48_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-48x48.png')
ANACONDA_ICON_64_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-64x64.png')
ANACONDA_ICON_75_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-75x75.png')
ANACONDA_ICON_128_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-128x128.png')
ANACONDA_ICON_256_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-256x256.png')
ANACONDA_ICON_512_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-512x512.png')
ANACONDA_ICON_1024_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-1024x1024.png')
ANACONDA_NAVIGATOR_LOGO = osp.join(IMAGE_PATH, 'anaconda-navigator-logo.png')

# TODO: Check copyright on this image
VIDEO_ICON_PATH = osp.join(IMAGE_PATH, 'video120x90.png')

# --- Application icons
# -----------------------------------------------------------------------------
GLUEVIZ_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'glueviz-icon-1024x1024.png')

IPYTHON_NOTEBOOK_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'ipython-notebook-icon-1024x1024.png')

IPYTHON_QTCONSOLE_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'ipython-qtconsole-icon-1024x1024.png')

NOTEBOOK_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'jupyter-icon-1024x1024.png')

ORANGE_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'orange-icon-1024x1024.png')

QTCONSOLE_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'qtconsole-icon-1024x1024.png')

SPYDER_ICON_1024_PATH = osp.join(IMAGE_PATH, 'spyder-icon-1024x1024.png')

RODEO_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'rodeo-icon-1024x1024.png')

VEUSZ_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'veusz-icon-1024x1024.png')

# --- Spinners
# -----------------------------------------------------------------------------
# http://preloaders.net/en/circular
SPINNER_PATH = osp.join(IMAGE_PATH, 'loading_spinner.gif')
SPINNER_16_PATH = osp.join(IMAGE_PATH, 'spinner-16x16.gif')
SPINNER_32_PATH = osp.join(IMAGE_PATH, 'spinner-32x32.gif')
SPINNER_GREEN_16_PATH = osp.join(IMAGE_PATH, 'spinner-green-16x16.gif')
SPINNER_WHITE_16_PATH = osp.join(IMAGE_PATH, 'spinner-white-16x16.gif')

COMBOBOX_ARROW_PATH = osp.join(IMAGE_PATH, 'combobox-arrow.png')
SCROLL_ARROW_UP_PATH = osp.join(IMAGE_PATH, 'scroll-arrow-up.png')
SCROLL_ARROW_DOWN_PATH = osp.join(IMAGE_PATH, 'scroll-arrow-down.png')


# Conda Package Manager
# -----------------------------------------------------------------------------
CONDA_MANAGER_INSTALLED = osp.join(IMAGE_PATH, 'conda-manager-installed.svg')
CONDA_MANAGER_NOT_INSTALLED = osp.join(IMAGE_PATH, 'conda-manager-not-installed.svg')
CONDA_MANAGER_ADD = osp.join(IMAGE_PATH, 'conda-manager-add.svg')
CONDA_MANAGER_REMOVE = osp.join(IMAGE_PATH, 'conda-manager-remove.svg')
CONDA_MANAGER_DOWNGRADE = osp.join(IMAGE_PATH, 'conda-manager-downgrade.svg')
CONDA_MANAGER_UPGRADE = osp.join(IMAGE_PATH, 'conda-manager-upgrade.svg')
CONDA_MANAGER_UPGRADE_ARROW = osp.join(IMAGE_PATH, 'conda-manager-upgrade-arrow.svg')
CONDA_MANAGER_CLOSE = osp.join(IMAGE_PATH, 'conda-manager-upgrade-arrow.svg')
CONDA_MANAGER_X = osp.join(IMAGE_PATH, 'conda-manager-x.svg')
CONDA_MANAGER_SEARCH = osp.join(IMAGE_PATH, 'conda-manager-magnifying-glass.svg')
WARNING_ICON = osp.join(IMAGE_PATH, 'icon-warning.svg')

==> anaconda-navigator-1.2.1-py35_0.tar.bz2: lib/python3.5/site-packages/anaconda_navigator/images/__init__.py <==
# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright 2016 Continuum Analytics, Inc.
#
# May be copied and distributed freely only as part of an Anaconda or
# Miniconda installation.
# -----------------------------------------------------------------------------
"""
This folder contains image files bundled with Anaconda Navigator package.

This folder is defined as a python module so that some convenience global
variables can be defined.
"""

# Standard library imports
from __future__ import absolute_import, division, print_function
import os.path as osp


IMAGE_PATH = osp.dirname(osp.realpath(__file__))

# --- Anaconda Logo
# -----------------------------------------------------------------------------
ANACONDA_ICON_16_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-16x16.png')
ANACONDA_ICON_24_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-24x24.png')
ANACONDA_ICON_32_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-32x32.png')
ANACONDA_ICON_48_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-48x48.png')
ANACONDA_ICON_64_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-64x64.png')
ANACONDA_ICON_75_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-75x75.png')
ANACONDA_ICON_128_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-128x128.png')
ANACONDA_ICON_256_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-256x256.png')
ANACONDA_ICON_512_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-512x512.png')
ANACONDA_ICON_1024_PATH = osp.join(IMAGE_PATH, 'anaconda-icon-1024x1024.png')
ANACONDA_NAVIGATOR_LOGO = osp.join(IMAGE_PATH, 'anaconda-navigator-logo.svg')

# TODO: Check copyright on this image
VIDEO_ICON_PATH = osp.join(IMAGE_PATH, 'default-content.png')

# --- Application icons
# -----------------------------------------------------------------------------
GLUEVIZ_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'glueviz-icon-1024x1024.png')

IPYTHON_NOTEBOOK_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'ipython-notebook-icon-1024x1024.png')

IPYTHON_QTCONSOLE_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'ipython-qtconsole-icon-1024x1024.png')

NOTEBOOK_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'jupyter-icon-1024x1024.png')

ORANGE_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'orange-icon-1024x1024.png')

QTCONSOLE_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'qtconsole-icon-1024x1024.png')

SPYDER_ICON_1024_PATH = osp.join(IMAGE_PATH, 'spyder-icon-1024x1024.png')

RODEO_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'rodeo-icon-1024x1024.png')

VEUSZ_ICON_1024_PATH = osp.join(
    IMAGE_PATH, 'veusz-icon-1024x1024.png')

# --- Spinners
# -----------------------------------------------------------------------------
# http://preloaders.net/en/circular
SPINNER_PATH = osp.join(IMAGE_PATH, 'loading_spinner.gif')
SPINNER_16_PATH = osp.join(IMAGE_PATH, 'spinner-16x16.gif')
SPINNER_32_PATH = osp.join(IMAGE_PATH, 'spinner-32x32.gif')
SPINNER_GREEN_16_PATH = osp.join(IMAGE_PATH, 'spinner-green-16x16.gif')
SPINNER_WHITE_16_PATH = osp.join(IMAGE_PATH, 'spinner-white-16x16.gif')

COMBOBOX_ARROW_PATH = osp.join(IMAGE_PATH, 'combobox-arrow.png')
SCROLL_ARROW_UP_PATH = osp.join(IMAGE_PATH, 'scroll-arrow-up.png')
SCROLL_ARROW_DOWN_PATH = osp.join(IMAGE_PATH, 'scroll-arrow-down.png')


# Conda Package Manager
# -----------------------------------------------------------------------------
CONDA_MANAGER_INSTALLED = osp.join(IMAGE_PATH, 'icons',
                                   'check-box-checked-active.svg')
CONDA_MANAGER_NOT_INSTALLED = osp.join(IMAGE_PATH, 'icons',
                                       'check-box-blank.svg')
CONDA_MANAGER_ADD = osp.join(IMAGE_PATH, 'icons', 'mark-install.svg')
CONDA_MANAGER_REMOVE = osp.join(IMAGE_PATH, 'icons', 'mark-remove.svg')
CONDA_MANAGER_DOWNGRADE = osp.join(IMAGE_PATH, 'icons', 'mark-downgrade.svg')
CONDA_MANAGER_UPGRADE = osp.join(IMAGE_PATH, 'icons', 'mark-upgrade.svg')
CONDA_MANAGER_UPGRADE_ARROW = osp.join(IMAGE_PATH, 'icons',
                                       'update-app-active.svg')
CONDA_MANAGER_SPACER = osp.join(IMAGE_PATH, 'conda-manager-spacer.svg')
CONDA_MANAGER_CLOSE = osp.join(IMAGE_PATH, 'conda-manager-upgrade-arrow.svg')
CONDA_MANAGER_X = osp.join(IMAGE_PATH, 'conda-manager-x.svg')
CONDA_MANAGER_SEARCH = osp.join(IMAGE_PATH,
                                'conda-manager-magnifying-glass.svg')
WARNING_ICON = osp.join(IMAGE_PATH, 'icons', 'warning-active.svg')
